create database thinker_cloud_device_service;
use thinker_cloud_device_service;
-- 创建 device_polling 表
create table IF NOT EXISTS device_polling
(
    id                  Int64,
    raw_data_id         Int64,
    timestamp           DateTime64(6),
    gateway_id          Int64,
    gateway_code        String,
    polling_id          String,
    type                Int32,
    content             String,
    last_frame_interval Int32
) ENGINE = MergeTree
      PARTITION BY toDate(timestamp)
      ORDER BY (timestamp, gateway_id,polling_id);


-- 创建 meter_data 表
create table IF NOT EXISTS meter_data
(
    id            Int64,
    value         String,
    meter_attr_id Int64,
    timestamp     DateTime64(6),
    dirty         UInt8
) ENGINE = ReplacingMergeTree(id)
      PARTITION BY toDate(timestamp)
      ORDER BY (timestamp, meter_attr_id);

-- 创建跳树索引
ALTER TABLE meter_data ADD INDEX meter_data_attr_id_vix meter_attr_id TYPE bloom_filter GRANULARITY 1;

-- 创建 meter_analysis 表
create table IF NOT EXISTS meter_analysis
(
    id            Int64,
    meter_attr_id Int64,
    value         String,
    original      UInt8,
    type          String,
    timestamp     DateTime64(6)
) ENGINE = MergeTree
      PARTITION BY toDate(timestamp)
      ORDER BY (timestamp, meter_attr_id);


-- 创建 reporting_raw_data 表
create table IF NOT EXISTS reporting_raw_data
(
    id          Int64,
    device_code String,
    payload     String,
    timestamp   DateTime64(6)
) ENGINE = MergeTree
      PARTITION BY toDate(timestamp)
      ORDER BY (timestamp, device_code);

-- 创建 meter_data_storage_extend 表
create table IF NOT EXISTS meter_data_storage_extend
(
    data_id                  Int64,
    functions         String,
    meter_attr_id          Int64,
    timestamp           DateTime64(6),
    value        String
) ENGINE = MergeTree
      PARTITION BY toMonday(timestamp)
      ORDER BY (timestamp, meter_attr_id);


-- 创建 gateway_log 表
create table IF NOT EXISTS gateway_log
(
    gateway_code                  String,
    level         String,
    offline_is         UInt8,
    content          String,
    timestamp           DateTime64(3)
) ENGINE = MergeTree
      PARTITION BY toMonth(timestamp)
      ORDER BY (timestamp,gateway_code,level, offline_is);


-- 创建 gateway_mqtt_log 表
create table gateway_mqtt_log
(
    gateway_code String,
    topic        String,
    content      String,
    timestamp    DateTime64(3)
)
    engine = MergeTree
        PARTITION BY toMonth(timestamp)
        ORDER BY (timestamp, gateway_code, topic);

-- device_log_info
create table device_log_info
(
    id               Int64,
    device_id        Int64,
    device_name      String,
    device_type_id   Int64,
    state            Int32,
    content          String,
    account          String,
    ip               String,
    business_type_id Int32,
    business_id      Int64,
    project_id       Int64,
    create_time      DateTime64(6),
    extended_info    String,
    account_id       Int64
)
    engine = MergeTree PARTITION BY toWeek(create_time)
        ORDER BY (create_time, device_id);
-- error_meter_data
CREATE TABLE error_meter_data
(

    `id` Int64,

    `description` String,

    `markers` String,

    `old_value` String,

    `new_value` String,

    `meter_attr_id` Int64,

    `timestamp` DateTime64(6)
)
ENGINE = MergeTree
PARTITION BY toDate(timestamp)
ORDER BY (timestamp,
 meter_attr_id)
SETTINGS index_granularity = 8192;


-- 创建 meter_event_log 表
create table IF NOT EXISTS meter_event_log
(
    id             Int64,
    event_id       Int64,
    create_time    DateTime64(6),
    event_value    String,
    original_value String,
    last_value     String,
    change_is      UInt8,
    event_value_desc String
) ENGINE = MergeTree
      PARTITION BY toDate(create_time)
      ORDER BY (create_time, event_id);